@@ -13,7 +13,7 @@ async fn sb_transaction_simple() -> Result<(), Box<dyn Error>> {
 
 	// DO insert
 	let fields = vec![("title", test_title_1).into()];
-	let sb = sqlb::insert("todo").data(fields);
+	let sb = sqlb::insert().table("todo").data(fields);
 	let mut db_tx = db_pool.begin().await?;
 	let row_affected = sqlx_exec::exec(&mut db_tx, &sb).await?;
 
